@@ -426,9 +426,12 @@ class GTK_Main(object):
         metadata_hbox = gtk.HBox()
         metadata_hbox.set_spacing(6)
         main_vbox.pack_start(metadata_hbox, True, False)
-
+        
+        self.cover_art_event_box = gtk.EventBox()
         self.cover_art = gtk.Image()
-        metadata_hbox.pack_start( self.cover_art, False, False )
+        self.cover_art_event_box.add(self.cover_art)
+        self.cover_art_event_box.connect('button-release-event', self.on_cover_clicked)
+        metadata_hbox.pack_start(self.cover_art_event_box, False, False)
 
         # vbox to hold metadata
         metadata_vbox = gtk.VBox()
@@ -599,6 +602,7 @@ class GTK_Main(object):
         self.menu_recent.set_submenu(menu_recent_sub)
 
     def on_recent_file_activate(self, widget, filepath):
+        print 'yoyoyo'
         self.play_file(filepath)
 
     @property
@@ -653,6 +657,9 @@ class GTK_Main(object):
         else:
             return True
 
+    def on_cover_clicked(self, widget, event):
+        self.play_pause_button.clicked()
+
     def open_file_callback(self, widget=None):
         if self.check_queue():
             filename = get_file_from_filechooser(self.main_window)
@@ -705,8 +712,11 @@ class GTK_Main(object):
             self.on_btn_play_pause_clicked()
         elif event.keyval == gtk.keysyms.F6: # fullscreen
             if self.fullscreen:
+                self.main_window.set_border_width(0)
                 self.main_window.unfullscreen()
             else:
+                # This makes the buttons easier to hit (N8x0's screen bezel!)
+                self.main_window.set_border_width(30)
                 self.main_window.fullscreen()
 
     def window_state_event(self, widget, event):
@@ -801,7 +811,7 @@ class GTK_Main(object):
             widget.set_text('')
             widget.hide()
 
-        self.cover_art.hide()
+        self.cover_art_event_box.hide()
         self.has_coverart = False
         self.set_metadata(metadata)
 
@@ -873,7 +883,7 @@ class GTK_Main(object):
 
     def set_coverart( self, pixbuf ):
         self.cover_art.set_from_pixbuf(pixbuf)
-        self.cover_art.show()
+        self.cover_art_event_box.show()
         self.has_coverart = True
 
     def set_metadata( self, tag_message ):
